@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 #include <config.h>
@@ -59,7 +70,7 @@
  *  @author Rory Toma, <rory@digeo.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: control.c,v 1.107 2007/07/25 12:54:28 hauk Exp $
+ *  @version \$Id: control.c,v 1.121 2009/02/13 09:18:05 hauk Exp $
  *
  *  @file
  */
@@ -68,13 +79,13 @@
 /* -------------------------------------------------------------- Prototypes */
 
 
-static void  do_start(Service_T);
-static int   do_stop(Service_T);
-static void  do_monitor(Service_T);
-static void  do_unmonitor(Service_T);
-static void *wait_start(void *);
-static int   wait_stop(Service_T);
-static void  do_depend(Service_T, int);
+static void do_start(Service_T);
+static int  do_stop(Service_T);
+static void do_monitor(Service_T);
+static void do_unmonitor(Service_T);
+static void wait_start(Service_T);
+static int  wait_stop(Service_T);
+static void do_depend(Service_T, int);
 
 
 /* ------------------------------------------------------------------ Public */
@@ -108,7 +119,7 @@ void control_service_daemon(const char *S, const char *action) {
     
   } else {
 
-    char *auth = Util_getBasicAuthHeader();
+    char *auth = Util_getBasicAuthHeaderMonit();
 
     if(socket_print(s,
          "POST /%s HTTP/1.0\r\n"
@@ -179,7 +190,7 @@ void control_service(const char *S, int A) {
           return;
         }
         if(!s->start) {
-          DEBUG("%s: Start method not defined -- process %s\n", prog, S);
+          LogError("%s: Start method not defined -- process %s\n", prog, S);
           Util_monitorSet(s);
           return;
         }
@@ -191,7 +202,7 @@ void control_service(const char *S, int A) {
 
     case ACTION_STOP:
       if(s->type==TYPE_PROCESS && !s->stop) {
-        DEBUG("%s: Stop method not defined -- process %s\n", prog, S);
+        LogError("%s: Stop method not defined -- process %s\n", prog, S);
         Util_monitorUnset(s);
         return;
       }
@@ -205,7 +216,7 @@ void control_service(const char *S, int A) {
 
     case ACTION_RESTART:
       if(s->type==TYPE_PROCESS && (!s->start || !s->stop)) {
-        DEBUG("%s: Start or stop method not defined -- process %s\n", prog, S);
+        LogError("%s: Start or stop method not defined -- process %s\n", prog, S);
         Util_monitorSet(s);
         return;
       }
@@ -290,25 +301,12 @@ static void do_start(Service_T s) {
   }
   
   if(s->start && (s->type!=TYPE_PROCESS || !Util_isProcessRunning(s))) {
-    int status;
-    pthread_t thread;
-
     LogInfo("'%s' start: %s\n", s->name, s->start->arg[0]);
     spawn(s, s->start, "Started");
     if(s->type==TYPE_PROCESS) {
       /* We only wait for a process type, other service types does not
        * have a pid file to watch */
-      LOCK(Run.mutex)
-        Run.wait_start++;
-      END_LOCK;
-      status= pthread_create(&thread, NULL, wait_start, s);
-      if(status != 0) {
-        LOCK(Run.mutex)
-          Run.wait_start--;
-        END_LOCK;
-	LogError("Warning: Failed to create the start controller thread. "
-	    "Thread error -- %s.\n", strerror(status));
-      }
+      wait_start(s);
     }
   }
   Util_monitorSet(s);
@@ -339,7 +337,6 @@ static int do_stop(Service_T s) {
   if(s->stop && (s->type!=TYPE_PROCESS || Util_isProcessRunning(s))) {
     LogInfo("'%s' stop: %s\n", s->name, s->stop->arg[0]);
     spawn(s, s->stop, "Stopped");
-
     if(s->type==TYPE_PROCESS) {
       /* Only wait for process service types */
       if(!wait_stop(s))
@@ -456,35 +453,23 @@ static void do_depend(Service_T s, int action) {
  * posted to notify the user.
  * @param service A Service to wait for
  */
-static void *wait_start(void *service) {
-
-  Service_T s= service;
-  int max_tries= Run.polltime;
+static void wait_start(Service_T s) {
+  int max_tries= s->start->timeout;
   
   ASSERT(s);
 
-  pthread_detach(pthread_self());
-
   while(max_tries-- && !Run.stopped) {
     if(Util_isProcessRunning(s))
       break;
     sleep(1);
   }
   
-  if(!Util_isProcessRunning(s)) {
-    Event_post(s, EVENT_EXEC, STATE_FAILED, s->action_EXEC,
-      "'%s' failed to start", s->name);
-  } else {
-    Event_post(s, EVENT_EXEC, STATE_PASSED, s->action_EXEC,
-      "'%s' started", s->name);
-  }
+  if(!Util_isProcessRunning(s))
+    Event_post(s, EVENT_EXEC, STATE_FAILED, s->action_EXEC, "failed to start");
+  else
+    Event_post(s, EVENT_EXEC, STATE_SUCCEEDED, s->action_EXEC, "started");
 
-  LOCK(Run.mutex)
-    Run.wait_start--;
-  END_LOCK;
-
-  return NULL;
-  
+  return;
 }
 
 
@@ -499,7 +484,7 @@ static void *wait_start(void *service) {
  */
 static int wait_stop(Service_T s) {
 
-  int max_tries= Run.polltime;
+  int max_tries= s->stop->timeout;
   
   ASSERT(s);
 
@@ -510,12 +495,10 @@ static int wait_stop(Service_T s) {
   }
 
   if(Util_isProcessRunning(s)) {
-    Event_post(s, EVENT_EXEC, STATE_FAILED, s->action_EXEC,
-      "'%s' failed to stop", s->name);
+    Event_post(s, EVENT_EXEC, STATE_FAILED, s->action_EXEC, "failed to stop");
     return FALSE;
   } else {
-    Event_post(s, EVENT_EXEC, STATE_PASSED, s->action_EXEC,
-      "'%s' stopped", s->name);
+    Event_post(s, EVENT_EXEC, STATE_SUCCEEDED, s->action_EXEC, "stopped");
   }
 
   return TRUE;
