@@ -33,7 +33,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: device_common.c,v 1.13 2009/02/13 09:18:12 hauk Exp $
+ *  @version \$Id: device_common.c,v 1.14 2009/05/04 19:37:14 martinp Exp $
  *
  *  @file
  */
@@ -103,7 +103,8 @@ char *device_path(Info_T inf, char *object) {
 
   if(S_ISREG(buf.st_mode) || S_ISDIR(buf.st_mode)) {
 
-    return strncpy(inf->mntpath, object, sizeof(inf->mntpath));
+    inf->mntpath[sizeof(inf->mntpath) - 1] = 0;
+    return strncpy(inf->mntpath, object, sizeof(inf->mntpath) - 1);
 
   } else if(S_ISBLK(buf.st_mode)) {
 
