@@ -33,7 +33,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_AIX.c,v 1.19 2009/02/13 09:18:12 hauk Exp $
+ *  @version \$Id: sysdep_AIX.c,v 1.20 2009/05/04 19:37:15 martinp Exp $
  *
  *  @file
  */
@@ -90,13 +90,14 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
     return NULL;
   }
 
-  /* First match is significant */
+  /* Finf->mntpathirst match is significant */
   while((mnt= getmntent(mntfd)) != NULL) {
 
     if(IS(blockdev, mnt->mnt_fsname)) {
 
       endmntent(mntfd);
-      return strncpy(inf->mntpath, mnt->mnt_dir, sizeof(inf->mntpath));
+      inf->mntpath[sizeof(inf->mntpath) - 1] = 0;
+      return strncpy(inf->mntpath, mnt->mnt_dir, sizeof(inf->mntpath) - 1);
 
     }
 
