@@ -33,7 +33,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_FREEBSD.c,v 1.22 2009/02/13 09:18:13 hauk Exp $
+ *  @version \$Id: sysdep_FREEBSD.c,v 1.23 2009/05/04 19:37:15 martinp Exp $
  *
  *  @file
  */
@@ -85,7 +85,8 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
     return NULL;
   }
 
-  return strncpy(inf->mntpath, usage.f_mntonname, sizeof(inf->mntpath));
+  inf->mntpath[sizeof(inf->mntpath) - 1] = 0;
+  return strncpy(inf->mntpath, usage.f_mntonname, sizeof(inf->mntpath) - 1);
 
 }
 
