@@ -33,7 +33,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_SOLARIS.c,v 1.21 2009/02/13 09:18:14 hauk Exp $
+ *  @version \$Id: sysdep_SOLARIS.c,v 1.22 2009/05/04 19:37:15 martinp Exp $
  *
  *  @file
  */
@@ -97,7 +97,8 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
     if(IS(blockdev, mnt.mnt_special)) {
 
       fclose(mntfd);
-      return strncpy(inf->mntpath, mnt.mnt_mountp, sizeof(inf->mntpath));
+      inf->mntpath[sizeof(inf->mntpath) - 1] = 0;
+      return strncpy(inf->mntpath, mnt.mnt_mountp, sizeof(inf->mntpath) - 1);
 
     }
 
