@@ -73,7 +73,7 @@
  *
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  * @author Martin Pala <martinp@tildeslash.com>
- * @version \$Id: event.c,v 1.93 2009/04/12 07:59:57 martinp Exp $
+ * @version \$Id: event.c,v 1.99 2009/05/28 21:35:29 martinp Exp $
  * @file
  */
 
@@ -89,6 +89,7 @@ EventTable_T Event_Table[]= {
   {EVENT_EXEC,       "Execution failed",        "Execution succeeded",        "Execution changed",        "Execution not changed"},
   {EVENT_FSFLAG,     "Filesystem flags failed", "Filesystem flags succeeded", "Filesystem flags changed", "Filesystem flags not changed"},
   {EVENT_GID,        "GID failed",              "GID succeeded",              "GID changed",              "GID not changed"},
+  {EVENT_HEARTBEAT,  "Heartbeat failed",        "Heartbeat succeeded",        "Heartbeat changed",        "Heartbeat not changed"},
   {EVENT_ICMP,       "ICMP failed",             "ICMP succeeded",             "ICMP changed",             "ICMP not changed"},
   {EVENT_INSTANCE,   "Monit instance failed",   "Monit instance succeeded",   "Monit instance changed",   "Monit instance not changed"},
   {EVENT_INVALID,    "Invalid type",            "Type succeeded",             "Type changed",             "Type not changed"},
@@ -127,13 +128,13 @@ static void Event_queue_update(Event_T, const char *);
  * @param s Optional message describing the event
  */
 void Event_post(Service_T service, long id, short state, EventAction_T action, char *s, ...) {
-  Event_T e = service->eventlist;
+  Event_T e;
 
   ASSERT(service);
   ASSERT(action);
   ASSERT(state == STATE_FAILED || state == STATE_SUCCEEDED || state == STATE_CHANGED || state == STATE_CHANGEDNOT);
 
-  if (e == NULL) {
+  if ((e = service->eventlist) == NULL) {
     /* Only first failed/changed event can initialize the queue for given event type,
      * thus succeeded events are ignored until first error. */
     if (state == STATE_SUCCEEDED || state == STATE_CHANGEDNOT)
@@ -161,7 +162,6 @@ void Event_post(Service_T service, long id, short state, EventAction_T action, c
       e->message = Util_formatString(s, ap, &l);
       va_end(ap);
     }
-    pthread_mutex_init(&e->mutex, NULL);
     service->eventlist = e;
   } else {
     /* Try to find the event with the same origin and type identification.
@@ -169,27 +169,23 @@ void Event_post(Service_T service, long id, short state, EventAction_T action, c
      * we share actions object address to identify event source. */
     do {
       if (e->action == action && e->id == id) {
-        LOCK(e->mutex)
-        {
-          gettimeofday(&e->collected, NULL);
+        gettimeofday(&e->collected, NULL);
 
-          /* Shift the existing event flags to the left
-           * and set the first bit based on actual state */
-          e->state_map <<= 1;
-          e->state_map |= ((state == STATE_SUCCEEDED || state == STATE_CHANGEDNOT) ? 0 : 1);
+        /* Shift the existing event flags to the left
+         * and set the first bit based on actual state */
+        e->state_map <<= 1;
+        e->state_map |= ((state == STATE_SUCCEEDED || state == STATE_CHANGEDNOT) ? 0 : 1);
 
-          /* Update the message */
-          if (s) {
-            long l;
-            va_list ap;
+        /* Update the message */
+        if (s) {
+          long l;
+          va_list ap;
 
-            FREE(e->message);
-            va_start(ap, s);
-            e->message = Util_formatString(s, ap, &l);
-            va_end(ap);
-          }
+          FREE(e->message);
+          va_start(ap, s);
+          e->message = Util_formatString(s, ap, &l);
+          va_end(ap);
         }
-        END_LOCK;
 	break;
       }
       e = e->next;
@@ -224,7 +220,6 @@ void Event_post(Service_T service, long id, short state, EventAction_T action, c
         e->message = Util_formatString(s, ap, &l);
         va_end(ap);
       }
-      pthread_mutex_init(&e->mutex, NULL);
       e->next = service->eventlist;
       service->eventlist = e;
     }
@@ -239,9 +234,7 @@ void Event_post(Service_T service, long id, short state, EventAction_T action, c
   } else
     e->count++;
 
-  LOCK(e->mutex)
-    handle_event(e);
-  END_LOCK;
+  handle_event(e);
 }
 
 
@@ -357,7 +350,7 @@ short Event_check_state(Event_T E, short S) {
   }
 
   /* the internal instance and action events are handled as changed any time since we need to deliver alert whenever it occurs */
-  if (E->id == EVENT_INSTANCE || E->id == EVENT_ACTION || (count >= action->count && state != E->state))
+  if (E->id == EVENT_INSTANCE || E->id == EVENT_ACTION || (count >= action->count && S != E->state))
     return TRUE;
   
   return FALSE;
@@ -813,6 +806,7 @@ static void Event_queue_add(Event_T E) {
     goto error;
 
   error:
+  fclose(file);
   if (!rv) {
     LogError("%s: Aborting event - unable to save event information to %s\n",  prog, file_name);
     if (unlink(file_name) < 0)
@@ -822,7 +816,6 @@ static void Event_queue_add(Event_T E) {
       Run.handler_queue[HANDLER_ALERT]++;
     if (!Run.handler_init && E->flag & HANDLER_MMONIT)
       Run.handler_queue[HANDLER_MMONIT]++;
-    fclose(file);
   }
 
   return;
@@ -885,12 +878,12 @@ static void Event_queue_update(Event_T E, const char *file_name) {
     goto error;
 
   error:
+  fclose(file);
   if (!rv) {
     LogError("%s: Aborting event - unable to update event information to %s\n",  prog, file_name);
     if (unlink(file_name) < 0)
       LogError("Failed to remove event file '%s' -- %s\n", file_name, STRERROR);
-  } else
-    fclose(file);
+  }
 
   return;
 }
