@@ -78,7 +78,7 @@
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: file.c,v 1.25 2009/02/13 09:18:06 hauk Exp $
+ *  @version \$Id: file.c,v 1.26 2009/05/02 20:16:06 martinp Exp $
  *
  *  @file
  */
@@ -497,8 +497,8 @@ void *File_readQueue(FILE *file, int *size) {
   if(fread(size, 1, sizeof(int), file) != sizeof(int) || ferror(file))
     goto error;
 
-  /* read data if any */
-  if(*size > 0) {
+  /* read data if any (allow 1MB at maximum to prevent enormous memory allocation) */
+  if(*size > 0 && *size < 1048576) {
     data = xcalloc(1, *size);
     if(fread(data, 1, *size, file) != *size || ferror(file)) {
       FREE(data);
