@@ -76,7 +76,7 @@ static void _gc_request(Request_T *);
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: gc.c,v 1.89 2009/02/13 09:18:07 hauk Exp $
+ *  @version \$Id: gc.c,v 1.93 2009/05/28 21:35:29 martinp Exp $
  *
  *  @file
  */
@@ -164,8 +164,6 @@ void gc_event(Event_T *e) {
   if((*e)->next)
     gc_event(&(*e)->next);
 
-  pthread_mutex_destroy(&(*e)->mutex);
-
   (*e)->action= NULL;
   FREE((*e)->source);
   FREE((*e)->group);
@@ -288,7 +286,7 @@ static void _gc_service(Service_T *s) {
   
   (*s)->next= NULL;
 
-  pthread_mutex_destroy(&(*s)->mutex);
+  assert(pthread_mutex_destroy(&(*s)->mutex) == 0);
 
   FREE(*s);
 
@@ -328,9 +326,10 @@ static void _gc_url(URL_T *url) {
 
 static void _gc_mail_server(MailServer_T *s) {
 
-  if(!s&&!*s) return;
+  if (! s || ! *s)
+    return;
   
-  if((*s)->next)
+  if ((*s)->next)
     _gc_mail_server(&(*s)->next);
   
   FREE((*s)->host);
