@@ -158,7 +158,7 @@ static char *get_service_status_text(Service_T);
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: cervlet.c,v 1.257 2009/03/28 10:37:44 martinp Exp $
+ *  @version \$Id: cervlet.c,v 1.260 2009/05/28 07:13:12 hauk Exp $
  *
  *  @file
  */
@@ -314,15 +314,14 @@ static void do_about(HttpRequest req, HttpResponse res) {
     "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
     "<a href='http://www.gnu.org/licenses/gpl.html'>GNU "
     "General Public License</a> for more details.</p>"
-    "<p style='padding-top:30px; text-align: center; font-size:18px'>"
-    "Please give <a href=\"http://mmonit.com/\">M/Monit</a> a try or "
-    "consider making a <a href=\"http://mmonit.com/monit/donate/\">"
+    "<p style='border-top:1px solid #ccc; padding-top:1em;'>"
+    "Running Monit on more than one server? Use <a href='http://mmonit.com/'>"
+    "M/Monit</a> to manage all your Monit instances.</p>"
+    "<p style='font-weight: bold;'>Please consider making a <a href=\"http://mmonit.com/monit/donate/\">"
     "donation</a> to support our work with Monit.</p>");
   out_print(res,
     "<center><p style='padding-top:20px;'>[Click <a href=\".\">here</a> to "
-    "go back to Monit]</p>");
-
-  FOOT
+    "go back to Monit]</p></body></html>");
 
 }
 
@@ -667,7 +666,8 @@ static void handle_do_action(HttpRequest req, HttpResponse res) {
           q = s;
         }
       }
-      q->token = xstrdup(token);
+      if (q)
+        q->token = xstrdup(token);
     }
 
     Run.doaction = TRUE; 
