@@ -55,8 +55,13 @@
 "  	text-decoration: underline;"\
 "  }"\
 "  .foot {"\
+"        padding-top:40px;"\
 "        font-size:10px;"\
-"        color: #666666;"\
+"        color: #333333;"\
+"  } "\
+"  .foot a {"\
+"        font-size:10px;"\
+"        color: #000000;"\
 "  } "\
 "  </style>"\
 "<meta HTTP-EQUIV=\"REFRESH\" CONTENT=%d>"\
@@ -92,8 +97,11 @@
 
 #define FOOT_HTML "</center>"\
 "<div align=\"center\" class=\"foot\" style=\"margin:20px auto\">"\
-"Copyright &copy; 2000-2009 by <a class=\"foot\" href=\"http://tildeslash.com/\">Tildeslash Ltd</a>."\
-" All Rights Reserved.</div></body></html>"
+"Copyright &copy; 2000-2009 <a href=\"http://tildeslash.com/\">Tildeslash</a>. All rights reserved. | "\
+"<a href=\"http://mmonit.com/monit/\">Monit web site</a> | "\
+"<a href=\"http://mmonit.com/wiki/\">Monit Wiki</a> | "\
+"<a href=\"http://mmonit.com/\">M/Monit</a>"\
+"</div></body></html>"
 
 
 #define HEAD(location, refresh) \
