@@ -111,7 +111,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: processor.c,v 1.66 2009/02/13 09:18:15 hauk Exp $
+ *  @version \$Id: processor.c,v 1.73 2009/05/09 15:11:39 martinp Exp $
  *
  *  @file
  */
@@ -541,7 +541,7 @@ static HttpRequest create_HttpRequest(Socket_T S) {
     return NULL;
   }
   Util_chomp(line);
-  if(sscanf(line, "%s %s HTTP/%3[1.0]", method, url, protocol) != 3) {
+  if(sscanf(line, "%1023s %1023s HTTP/%3[1.0]", method, url, protocol) != 3) {
     internal_error(S, SC_BAD_REQUEST, "Cannot parse request");
     return NULL;
   }
@@ -557,8 +557,8 @@ static HttpRequest create_HttpRequest(Socket_T S) {
   req->protocol= xstrdup(protocol); 
   create_headers(req);
   if(!create_parameters(req)) {
-    internal_error(S, SC_BAD_REQUEST, "Cannot parse Request parameters");
     destroy_HttpRequest(req);
+    internal_error(S, SC_BAD_REQUEST, "Cannot parse Request parameters");
     return NULL;
   }
   return req;
@@ -625,8 +625,9 @@ static int create_parameters(HttpRequest req) {
   if(IS(req->method, METHOD_POST) && get_header(req, "Content-Length")) {
     int n;
     int len; 
-    Socket_T S= req->S;
-    if(1 != sscanf(get_header(req, "Content-Length"), "%d", &len)) {
+    Socket_T S = req->S;
+    const char *cl = get_header(req, "Content-Length");
+    if(! cl || sscanf(cl, "%d", &len) != 1) {
       return FALSE;
     }
     if(len < 0 || len >= REQ_STRLEN)
@@ -641,7 +642,8 @@ static int create_parameters(HttpRequest req) {
     char *p;
     if(NULL != (p= strchr(req->url, '?'))) {
       *p++= 0;
-      strncpy(query_string, p, REQ_STRLEN);
+      strncpy(query_string, p, sizeof(query_string) - 1);
+      query_string[sizeof(query_string) - 1] = 0;
     }
   }
   if(*query_string) {
@@ -764,7 +766,8 @@ static int basic_authenticate(HttpRequest req) {
   if(! (credentials && Util_startsWith(credentials, "Basic "))) {
     return FALSE;
   }
-  strncpy(buf, &credentials[6], STRLEN);
+  strncpy(buf, &credentials[6], sizeof(buf) - 1);
+  buf[sizeof(buf) - 1] = 0;
   if((n= decode_base64((unsigned char*)uname, buf))<=0) {
     return FALSE;
   }
