@@ -90,7 +90,7 @@
   *
   *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
   *
-  *  @version \$Id: log.c,v 1.42 2009/02/13 09:18:07 hauk Exp $
+  *  @version \$Id: log.c,v 1.43 2009/05/03 07:48:20 martinp Exp $
   *
   *  @file
  */
@@ -322,17 +322,14 @@ static int open_log() {
  * macro in monitor.h
  */
 static char *timefmt(char *t, int size) {
-
   time_t now;
   struct tm tm;
 
   time(&now);
-  if (!strftime(t, size, TIMEFORMAT, localtime_r(&now, &tm))) {
-    *t= 0;
-  }
-
+  localtime_r(&now, &tm);
+  if ( !strftime(t, size, TIMEFORMAT, &tm))
+    *t = 0;
   return t;
-
 }
 
 
