@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2000-2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +11,25 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
+
 #include <config.h>
+#include <locale.h>
 
 #ifdef HAVE_STDIO_H
 #include <stdio.h>
@@ -80,7 +93,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: monitor.c,v 1.136 2007/07/25 12:54:29 hauk Exp $
+ *  @version \$Id: monitor.c,v 1.149 2009/03/24 19:49:05 martinp Exp $
  *
  *  @file
  */
@@ -109,7 +122,7 @@ static RETSIGTYPE do_wakeup(int);  /* Signalhandler for a daemon wakeup call */
  * The Prime mover
  */
 int main(int argc, char **argv) {
-
+  setlocale(LC_ALL, "C");
   prog= Util_basename(argv[0]);
   init_env();
   handle_options(argc, argv);
@@ -297,10 +310,6 @@ static void do_reinit() {
      since the http thread is stopped) */
   State_save();
 
-  /* wait for all wait_start threads to finish */
-  while(Run.wait_start)
-    sleep(1);
-
   /* Run the garbage collector */
   gc();
 
@@ -338,8 +347,7 @@ static void do_reinit() {
     monit_http(START_HTTP);
 
   /* send the monit startup notification */
-  Event_post(Run.system, EVENT_INSTANCE, STATE_FAILED,
-    Run.system->action_MONIT_RELOAD, "Monit reloaded");
+  Event_post(Run.system, EVENT_INSTANCE, STATE_CHANGED, Run.system->action_MONIT_RELOAD, "Monit reloaded");
 
 }
 
@@ -361,12 +369,12 @@ static void do_action(char **args) {
             IS(action, "monitor")   ||
             IS(action, "unmonitor") ||
             IS(action, "restart")      ) {
-    if(service) {
+    if(Run.mygroup || service) {
 
       void (*_control_service)(const char *, const char *)=
         exist_daemon()?control_service_daemon:control_service_string;
 
-      if(IS(service, "all")) {
+      if(Run.mygroup || IS(service, "all")) {
 
         Service_T s= NULL;
 
@@ -429,15 +437,10 @@ static void do_exit() {
     LogInfo("%s daemon with pid [%d] killed\n", prog, (int)getpid());
 
     /* send the monit stop notification */
-    Event_post(Run.system, EVENT_INSTANCE, STATE_FAILED,
-      Run.system->action_MONIT_STOP, "Monit stopped");
+    Event_post(Run.system, EVENT_INSTANCE, STATE_CHANGED, Run.system->action_MONIT_STOP, "Monit stopped");
 
   }
 
-  /* wait for all wait_start threads to finish */
-  while(Run.wait_start)
-    sleep(1);
-
   gc();
 
   exit(0);
@@ -482,8 +485,9 @@ static void do_default() {
       monit_http(START_HTTP);
     
     /* send the monit startup notification */
-    Event_post(Run.system, EVENT_INSTANCE, STATE_FAILED,
-      Run.system->action_MONIT_START, "Monit started");
+    Event_post(Run.system, EVENT_INSTANCE, STATE_CHANGED, Run.system->action_MONIT_START, "Monit started");
+
+    sleep(Run.startdelay);
 
     while(TRUE) {
 
@@ -503,11 +507,6 @@ static void do_default() {
         do_exit();
       } else if(Run.doreload) {
         do_reinit();
-      } else {
-        Event_post(Run.system, EVENT_INSTANCE, STATE_PASSED,
-          Run.system->action_MONIT_START, "Monit has not changed");
-        Event_post(Run.system, EVENT_INSTANCE, STATE_PASSED,
-          Run.system->action_MONIT_RELOAD, "Monit has not changed");
       }
       
     }
@@ -634,7 +633,7 @@ static void help() {
   printf("Options are as follows:\n");
   printf(" -c file       Use this control file\n");
   printf(" -d n          Run as a daemon once per n seconds\n");
-  printf(" -g name       Set group name for start, stop, restart and status\n");
+  printf(" -g name       Set group name for start, stop, restart, monitor and unmonitor\n");
   printf(" -l logfile    Print log information to this file\n");
   printf(" -p pidfile    Use this lock file in daemon mode\n");
   printf(" -s statefile  Set the file monit should write state information to\n");
@@ -672,7 +671,7 @@ static void help() {
 static void version() {
   
   printf("This is monit version %s\n", VERSION);
-  printf("Copyright (C) 2000-2007 by the monit project group.");
+  printf("Copyright (C) 2000-2009 by Tildeslash Ltd.");
   printf(" All Rights Reserved.\n");
 
 }
