@@ -32,6 +32,7 @@
 #define MONITOR_H
 
 #include <config.h>
+#include <assert.h>
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -246,8 +247,8 @@ Sigfunc *signal(int signo, Sigfunc * func);
 
 
 #define LOCK(mutex) do { pthread_mutex_t *_yymutex = &(mutex); \
-        pthread_mutex_lock(_yymutex);
-#define END_LOCK pthread_mutex_unlock(_yymutex); } while (0)
+        assert(pthread_mutex_lock(_yymutex)==0);
+#define END_LOCK assert(pthread_mutex_unlock(_yymutex)==0); } while (0)
 
 
 /** ---------------------------------- Object Constructor/"Destructor" macro */
@@ -739,7 +740,6 @@ typedef struct myservice {
     char             *message;    /**< Optional message describing the event */
     EventAction_T     action;           /**< Description of the event action */
     /** For internal use */
-    pthread_mutex_t   mutex;      /**< Mutex used for action synchronization */
     struct myevent   *next;                         /**< next event in chain */
     struct myevent   *previous;                 /**< previous event in chain */
   } *eventlist;                                     /**< Pending events list */
