@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 
@@ -69,7 +80,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Dave Cheney <dcheney@redbubble.com> (Updated for Tiger)
  *
- *  @version \$Id: sysdep_DARWIN.c,v 1.36 2007/11/05 21:50:04 hauk Exp $
+ *  @version \$Id: sysdep_DARWIN.c,v 1.44 2009/02/13 09:18:16 hauk Exp $
  *
  *  @file
  */
@@ -107,8 +118,8 @@ int init_process_info_sysdep(void) {
   mib[0] = CTL_HW;
 
   mib[1] = HW_NCPU;
-  len    = sizeof(num_cpus);
-  if(sysctl(mib, 2, &num_cpus, &len, NULL, 0) == -1)
+  len    = sizeof(systeminfo.cpus);
+  if(sysctl(mib, 2, &systeminfo.cpus, &len, NULL, 0) == -1)
   {
     DEBUG("system statistic error -- cannot get cpu count: %s\n", STRERROR);
     return FALSE;
@@ -157,13 +168,13 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
   }
 
   if(sysctl(mib, 4, NULL, &bufSize, NULL, 0) < 0) {
-    LogError("system statistic error -- sysctl failed");
+    LogError("system statistic error -- sysctl failed\n");
     return FALSE;
   }
   pinfo = (struct kinfo_proc *)xcalloc(1, bufSize);
 
   if(sysctl(mib, 4, pinfo, &bufSize, NULL, 0)) {
-    LogError("system statistic error -- sysctl failed");
+    LogError("system statistic error -- sysctl failed\n");
     free(pinfo);
     return FALSE;
   }
@@ -197,6 +208,7 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
         pt[i].mem_kbyte = (unsigned long)(taskinfo.resident_size / 1024);
         pt[i].cputime = (long)((taskinfo.user_time.seconds      + taskinfo.system_time.seconds)      * 10     +
                                (taskinfo.user_time.microseconds + taskinfo.system_time.microseconds) / 100000);
+        pt[i].cpu_percent = 0;
       }
       if(task_threads(task, &threadtable, &threadtable_size) == KERN_SUCCESS) {
         int j;
@@ -208,6 +220,7 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
             if((threadinfo->flags & TH_FLAGS_IDLE) == 0) {
               pt[i].cputime += (long)((threadinfo->user_time.seconds      + threadinfo->system_time.seconds)      * 10     +
                                       (threadinfo->user_time.microseconds + threadinfo->system_time.microseconds) / 100000);
+              pt[i].cpu_percent = 0;
             }
           }
           mach_port_deallocate(mytask, threadtable[j]);
@@ -292,9 +305,9 @@ int used_system_cpu_sysdep(SystemInfo_T *si) {
     total_old = total_new;
 
     si->total_cpu_user_percent =
-      (total > 0)?(int)(1000 * (double)(cpu_info.cpu_ticks[CPU_STATE_USER] - cpu_user_old) / total):0;
+      (total > 0)?(int)(1000 * (double)(cpu_info.cpu_ticks[CPU_STATE_USER] - cpu_user_old) / total):-10;
     si->total_cpu_syst_percent =
-      (total > 0)?(int)(1000 * (double)(cpu_info.cpu_ticks[CPU_STATE_SYSTEM] - cpu_syst_old) / total):0;
+      (total > 0)?(int)(1000 * (double)(cpu_info.cpu_ticks[CPU_STATE_SYSTEM] - cpu_syst_old) / total):-10;
     si->total_cpu_wait_percent =
       0; /* there is no wait statistic available */
 
