@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 
@@ -79,14 +90,22 @@
 #include <nlist.h>
 #endif
 
+#ifdef HAVE_SYS_DK_H
+#include <sys/dk.h>
+#endif
+
 #include "monitor.h"
 #include "process.h"
 #include "process_sysdep.h"
 
-#define NPROCS 10000
-static struct pst_status psall[NPROCS];
-
-static int page_size;
+static int         page_size;
+static int         nproc;
+static long        cpu_total_old = 0;
+static long        cpu_user_old = 0;
+static long        cpu_syst_old = 0;
+static long        cpu_wait_old = 0;
+struct pst_dynamic pst_dyn;
+struct pst_status *psall;
 
 /**
  *  System dependent resource gathering code for HP/UX.
@@ -94,7 +113,8 @@ static int page_size;
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Joe Bryant <JBryant@RiteAid.com>
- *  @version \$Id: sysdep_HPUX.c,v 1.20 2007/07/25 12:54:32 hauk Exp $
+ *  @author Martin Pala, <martinp@tildeslash.com>
+ *  @version \$Id: sysdep_HPUX.c,v 1.35 2009/02/13 09:18:17 hauk Exp $
  *
  *  @file
  */
@@ -111,7 +131,7 @@ int init_process_info_sysdep(void) {
 
   if (pstat_getdynamic(&psd,sizeof(psd),(size_t)1,0)!=-1) {
 
-    num_cpus=psd.psd_proc_cnt;
+    systeminfo.cpus=psd.psd_proc_cnt;
 
   } else {
 
@@ -121,9 +141,7 @@ int init_process_info_sysdep(void) {
 
   if (pstat_getstatic(&pst, sizeof(pst), (size_t) 1, 0) != -1) {
 
-    systeminfo.mem_kbyte_max=(unsigned long)(
-      (double)pst.physical_memory * (double)pst.page_size / 1024.0
-    ); 
+    systeminfo.mem_kbyte_max=(unsigned long)(pst.physical_memory * (pst.page_size / 1024)); 
     page_size=pst.page_size;
 
   } else {
@@ -172,12 +190,11 @@ int getloadavg_sysdep (double *a, int na) {
   return TRUE;
 }
 
+
 /**
- * Read all processes of the proc files system to initialize
- * the process tree (sysdep version... but should work for
- * all procfs based unices)
+ * Read all processes to initialize the process tree
  * @param reference  reference of ProcessTree
- * @return treesize>0 if succeeded otherwise =0.
+ * @return treesize>0 if succeeded otherwise 0.
  */
 int initprocesstree_sysdep(ProcessTree_T ** reference) {
 
@@ -189,12 +206,15 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
 
   /* Gather process data */
 
-  if ((treesize=pstat_getproc(psall,
-                              (size_t) NPROCS* sizeof(struct pst_status),
-                              (size_t) NPROCS, 0))==-1) {
+  pstat_getdynamic(&pst_dyn, sizeof(struct pst_dynamic), 1, 0);
+  nproc = pst_dyn.psd_activeprocs;
 
+  if ((psall = (struct pst_status *) xresize(psall, nproc * sizeof(struct pst_status))) == NULL)
+        return 0;
+
+  if ((treesize=pstat_getproc(psall, sizeof(struct pst_status), nproc , 0))==-1) {
+    LogError("system statistic error 1 -- pstat_getproc failed: %s\n", strerror(errno));
     return 0;
-
   }
 
   /* Allocate the tree */
@@ -212,19 +232,13 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
 
     pt[i].time = get_float_time();
 
-    /*
-     * jiffies -> seconds = 1 / HZ
-     * HZ is defined in "asm/param.h"  and it is usually 1/100s but on
-     * alpha system it is 1/1024s
-     */
-
-    pt[i].cputime =  ( psall[i].pst_utime + psall[i].pst_stime ) * 10 / HZ;
-    pt[i].mem_kbyte = (unsigned long)(((double)psall[i].pst_rssize)/1024.0 *
-                               page_size);
+    pt[i].cputime =  psall[i].pst_utime + psall[i].pst_stime * 10;
+    pt[i].cpu_percent = (int)(1000. * psall[i].pst_pctcpu / (float)systeminfo.cpus);
+    pt[i].mem_kbyte = (unsigned long)(psall[i].pst_rssize * (page_size / 1024.0));
 
     /* State is Zombie -> then we are a Zombie ... clear or? (-: */
 
-    if ( psall[i].pst_stat || PS_ZOMBIE ) {
+    if ( psall[i].pst_stat == PS_ZOMBIE ) {
 
       pt[i].status_flag |= PROCESS_ZOMBIE;
       
@@ -246,9 +260,20 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
  * @return: TRUE if successful, FALSE if failed (or not available)
  */
 int used_system_memory_sysdep(SystemInfo_T *si) {
+  struct pst_static pst;
+  struct pst_dynamic psd;
 
-  return FALSE;
+  if(pstat_getstatic(&pst, sizeof(pst), (size_t)1, 0) == -1) {
+    LogError("system statistic error -- pstat_getstatic failed: %s\n", STRERROR);
+    return FALSE;
+  }
+  if(pstat_getdynamic(&psd, sizeof(psd), (size_t)1, 0) == -1) {
+    LogError("system statistic error -- pstat_getdynamic failed: %s\n", STRERROR);
+    return FALSE;
+  }
 
+  si->total_mem_kbyte = (unsigned long)((pst.physical_memory - psd.psd_free) * (pst.page_size/1024));
+  return TRUE;
 }
 
 
@@ -257,7 +282,37 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
  * @return: TRUE if successful, FALSE if failed (or not available)
  */
 int used_system_cpu_sysdep(SystemInfo_T *si) {
+  int                i;
+  long               cpu_total;
+  long               cpu_total_new = 0;
+  long               cpu_user = 0;
+  long               cpu_syst = 0;
+  long               cpu_wait = 0;
+  struct pst_dynamic psd;
 
-  return FALSE;
-  
+  pstat_getdynamic(&psd, sizeof(psd), 1, 0);
+
+  for(i = 0; i < CPUSTATES; i++)
+  {
+    cpu_total_new += psd.psd_cpu_time[i];
+  }
+  cpu_total     = cpu_total_new - cpu_total_old;
+  cpu_total_old = cpu_total_new;
+  cpu_user      = psd.psd_cpu_time[CP_USER] + psd.psd_cpu_time[CP_NICE];
+  cpu_syst      = psd.psd_cpu_time[CP_SYS];
+  cpu_wait      = psd.psd_cpu_time[CP_WAIT];
+
+  si->total_cpu_user_percent =
+    (cpu_total > 0)?(int)(1000 * (double)(cpu_user - cpu_user_old) / cpu_total):-10;
+  si->total_cpu_syst_percent =
+    (cpu_total > 0)?(int)(1000 * (double)(cpu_syst - cpu_syst_old) / cpu_total):-10;
+  si->total_cpu_wait_percent =
+    (cpu_total > 0)?(int)(1000 * (double)(cpu_wait - cpu_wait_old) / cpu_total):-10;
+
+  cpu_user_old = cpu_user;
+  cpu_syst_old = cpu_syst;
+  cpu_wait_old = cpu_wait;
+
+  return TRUE;
 }
+
