@@ -101,7 +101,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Arkadiusz Miskiewicz <arekm@pld-linux.org>
  *
- *  @version \$Id: sysdep_LINUX.c,v 1.53 2009/02/27 20:09:39 martinp Exp $
+ *  @version \$Id: sysdep_LINUX.c,v 1.54 2009/05/02 19:54:07 martinp Exp $
  *
  *  @file
  */
@@ -350,12 +350,6 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
 
   si->total_mem_kbyte = systeminfo.mem_kbyte_max - mem_free - buffers - cached;
 
-  if(si->total_mem_kbyte < 0)
-  {
-    LogError("system statistic error -- memory usage statistic error\n");
-    goto error;
-  }
-
   return TRUE;
 
   error:
