@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 
@@ -68,7 +79,7 @@
  *  @author Rory Toma <rory@digeo.com>
  *  @author Martin Pala<martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_NETBSD.c,v 1.7 2007/07/25 12:54:32 hauk Exp $
+ *  @version \$Id: sysdep_NETBSD.c,v 1.14 2009/02/13 09:18:18 hauk Exp $
  *
  *  @file
  */
@@ -105,8 +116,8 @@ int init_process_info_sysdep(void) {
   mib[0] = CTL_HW;
 
   mib[1] = HW_NCPU;
-  len    = sizeof(num_cpus);
-  if(sysctl(mib, 2, &num_cpus, &len, NULL, 0) == -1)
+  len    = sizeof(systeminfo.cpus);
+  if(sysctl(mib, 2, &systeminfo.cpus, &len, NULL, 0) == -1)
   {
     DEBUG("system statistic error -- cannot get cpu count: %s\n", STRERROR);
     return FALSE;
@@ -174,6 +185,7 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
     pt[i].cputime   = (long)((pinfo[i].kp_proc.p_rtime.tv_sec * 10) +
                              (pinfo[i].kp_proc.p_rtime.tv_usec / 100000)
                             );
+    pt[i].cpu_percent  = 0;
     pt[i].mem_kbyte = (unsigned long)(pinfo[i].kp_eproc.e_vm.vm_rssize * pagesize_kbyte);
     if(pinfo[i].kp_proc.p_stat == SZOMB)
     {
@@ -249,9 +261,9 @@ int used_system_cpu_sysdep(SystemInfo_T *si) {
   total_old = total_new;
 
   si->total_cpu_user_percent =
-    (total > 0)?(int)(1000 * (double)(cp_time[CP_USER] - cpu_user_old) / total):0;
+    (total > 0)?(int)(1000 * (double)(cp_time[CP_USER] - cpu_user_old) / total):-10;
   si->total_cpu_syst_percent =
-    (total > 0)?(int)(1000 * (double)(cp_time[CP_SYS] - cpu_syst_old) / total):0;
+    (total > 0)?(int)(1000 * (double)(cp_time[CP_SYS] - cpu_syst_old) / total):-10;
   si->total_cpu_wait_percent =
     0; /* there is no wait statistic available */
 
