@@ -71,7 +71,7 @@ static int check_apache_stat(Socket_T s);
  * even with ExtendedStatus Off on Apache config file.
  *
  * @author David Fletcher, <david@megapico.co.uk>
- * @version \$Id: apache_status.c,v 1.13 2009/02/13 09:18:19 hauk Exp $
+ * @version \$Id: apache_status.c,v 1.14 2009/05/02 15:01:13 martinp Exp $
  * @file
  */
 int check_apache_status(Socket_T s) {
@@ -114,7 +114,7 @@ static int check_apache_stat(Socket_T s) {
   int scored = 0;
   int errors = 0;
   char line[READ_SIZE];
-  char search_string[READ_SIZE];
+  char search_string[READ_SIZE + 1];
 
   int loglimit= 0;
   int closelimit= 0;
@@ -157,7 +157,7 @@ static int check_apache_stat(Socket_T s) {
 
   while(NULL != socket_readln(s, line, READ_SIZE)) {
     if(Util_startsWith(line, "Scoreboard")) {   
-      if(1 != sscanf(line, "%*s%*[: ]%s", search_string)) {
+      if(1 != sscanf(line, "%*s%*[: ]%1024s", search_string)) {
        Util_chomp(line);
        LogError("APACHE-STATUS error: parsing Apache status response '%s'\n",
          line);
