@@ -56,7 +56,7 @@
  *
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: generic.c,v 1.27 2009/03/11 20:31:27 hauk Exp $
+ *  @version \$Id: generic.c,v 1.29 2009/05/04 20:00:30 martinp Exp $
  *
  *  @file
  */
@@ -72,7 +72,7 @@ int check_generic(Socket_T s) {
   if(socket_get_Port(s))
     g= ((Port_T)(socket_get_Port(s)))->generic;
     
-  buf= xcalloc(sizeof(char), Run.expectbuffer + 1);
+  buf = xcalloc(sizeof(char), Run.expectbuffer + 1);
 
   while (g != NULL) {
     
@@ -80,11 +80,12 @@ int check_generic(Socket_T s) {
       
       /* Unescape any \0x00 escaped chars in g's send string 
       to allow sending a string containing \0 bytes also */
-      char *X= xstrdup(g->send);
-      int l= Util_handle0Escapes(X);
+      char *X = xstrdup(g->send);
+      int l = Util_handle0Escapes(X);
       
       if(socket_write(s, X, l) < 0) {
         LogError("GENERIC: error sending data -- %s\n", STRERROR);
+        FREE(X);
         FREE(buf);
         return FALSE;
       } else
@@ -107,7 +108,7 @@ int check_generic(Socket_T s) {
       regex_return= regexec(g->expect, buf, 0, NULL, 0);
       if (regex_return != 0) {
         char e[STRLEN];
-        regerror(regex_return, 0, e, STRLEN);
+        regerror(regex_return, g->expect, e, STRLEN);
         LogError("GENERIC: receiving unexpected data [%s] -- %s\n", Util_trunc(buf, STRLEN - 4), e);
         FREE(buf);
         return FALSE;
