@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 #include <config.h>
@@ -51,10 +62,12 @@ static Protocol_T mypostfix_policy= NULL;
 static Protocol_T mypop= NULL;
 static Protocol_T mysmtp= NULL;
 static Protocol_T myssh= NULL;
+static Protocol_T mylmtp= NULL;
 static Protocol_T myrdate= NULL;
 static Protocol_T myrsync= NULL;
 static Protocol_T mytns= NULL;
 static Protocol_T mypgsql= NULL;
+static Protocol_T mysip= NULL;
 
 
 /**
@@ -63,7 +76,7 @@ static Protocol_T mypgsql= NULL;
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: protocol.c,v 1.30 2007/07/25 12:54:33 hauk Exp $
+ *  @version \$Id: protocol.c,v 1.36 2009/02/13 09:18:21 hauk Exp $
  *
  *  @file
  */
@@ -92,10 +105,12 @@ void gc_protocols() {
   FREE(mypop);
   FREE(mysmtp);
   FREE(myssh);
+  FREE(mylmtp);
   FREE(myrdate);
   FREE(myrsync);
   FREE(mytns);
   FREE(mypgsql);
+  FREE(mysip);
 
 }
 
@@ -218,6 +233,16 @@ void *create_mysql() {
 }
 
 
+void *create_sip() {
+  if(mysip == NULL) {
+    NEW(mysip);
+    mysip->name= "SIP";
+    mysip->check= check_sip;
+  }
+  return mysip;
+}
+
+
 void *create_nntp() {
   if(mynntp == NULL) {
     NEW(mynntp);
@@ -267,6 +292,15 @@ void *create_smtp() {
   return mysmtp;
 }
 
+void *create_lmtp() {
+  if(mylmtp == NULL) {
+    NEW(mylmtp);
+    mylmtp->name= "LMTP";
+    mylmtp->check= check_lmtp;
+  }
+  return mylmtp;
+}
+
 
 void *create_ssh() {
   if(myssh == NULL) {
