@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 
@@ -48,6 +59,8 @@
 #define P_TNS            20
 #define P_PGSQL          21
 #define P_CLAMAV         22
+#define P_SIP            23
+#define P_LMTP           24
 
 void  gc_protocols();
 
@@ -74,6 +87,8 @@ void* create_rdate();
 void* create_rsync();
 void* create_tns();
 void* create_pgsql();
+void* create_sip();
+void* create_lmtp();
 
 /* "Package" locale Protocol routines */
 int check_apache_status(Socket_T);
@@ -98,6 +113,8 @@ int check_rdate(Socket_T);
 int check_rsync(Socket_T);
 int check_tns(Socket_T);
 int check_pgsql(Socket_T);
+int check_sip(Socket_T);
+int check_lmtp(Socket_T);
 
 
 #endif
