@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 #include <config.h>
@@ -34,7 +45,7 @@
 
 
 /* Private prototypes */
-static int send(Socket_T s, char *msg);
+static int say(Socket_T s, char *msg);
 static int expect(Socket_T s, int expect, int log);
 
 
@@ -46,7 +57,7 @@ static int expect(Socket_T s, int expect, int log);
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Michael Amster, <mamster@webeasy.com>
  *
- *  @version \$Id: smtp.c,v 1.33 2007/07/25 12:54:33 hauk Exp $
+ *  @version \$Id: smtp.c,v 1.38 2009/02/13 09:18:22 hauk Exp $
  *
  *  @file
  */
@@ -57,13 +68,13 @@ int check_smtp(Socket_T s) {
   if(!expect(s, 220, TRUE))
     return FALSE;
   
-  if(!(send(s, "EHLO localhost\r\n") && expect(s, 250, FALSE))) {
+  if(!(say(s, "EHLO localhost\r\n") && expect(s, 250, FALSE))) {
     /* Try HELO also before giving up as of rfc2821 4.1.1.1 */
-    if(!(send(s, "HELO localhost\r\n") && expect(s, 250, TRUE)))
+    if(!(say(s, "HELO localhost\r\n") && expect(s, 250, TRUE)))
       return FALSE;
   }
 
-  if(!(send(s, "QUIT\r\n") && expect(s, 221, TRUE)))
+  if(!(say(s, "QUIT\r\n") && expect(s, 221, TRUE)))
     return FALSE;
     
   return TRUE;
@@ -74,7 +85,7 @@ int check_smtp(Socket_T s) {
 /* --------------------------------------------------------------- Private */
 
 
-static int send(Socket_T s, char *msg) {
+static int say(Socket_T s, char *msg) {
   
   if(socket_write(s, msg, strlen(msg)) < 0) {
     LogError("SMTP: error sending data -- %s\n", STRERROR);
