@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 
@@ -29,7 +40,7 @@
  * communication between two machines. 
  * 
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- * @version \$Id: socket.h,v 1.27 2007/09/05 08:43:36 hauk Exp $
+ * @version \$Id: socket.h,v 1.34 2009/02/13 09:18:10 hauk Exp $
  * @file
  */
 
@@ -111,6 +122,14 @@ void socket_free(Socket_T *S);
 int socket_is_ready(Socket_T S);
 
 
+/**
+ * Return TRUE if the connection is encrypted with SSL
+ * @param S A Socket object
+ * @return TRUE if SSL is used otherwise FALSE
+ */
+int socket_is_secure(Socket_T S);
+
+
 /**
  * Get the underlying socket descriptor
  * @param S A Socket object
@@ -153,6 +172,22 @@ int socket_get_remote_port(Socket_T S);
 const char *socket_get_remote_host(Socket_T S);
 
 
+/**
+ * Get the local (ephemeral) port number this socket is using.
+ * @param S A Socket object
+ * @return The port number on success otherwise -1
+ */
+int socket_get_local_port(Socket_T S);
+
+
+/**
+ * Get the local interface IP address
+ * @param S A Socket object
+ * @return The local host interface address or NULL if an error occurred
+ */
+const char *socket_get_local_host(Socket_T S);
+
+
 /**
  * Switches a connected socket to ssl.
  * @param S The already connected socket
@@ -222,4 +257,12 @@ char *socket_readln(Socket_T S, char *s, int size);
 void socket_reset(Socket_T S);
 
 
+/**
+ * Shut down the writing side of the socket
+ * @param S A Socket object
+ * @return TRUE if the write side was shutdown otherwise FALSE 
+ */
+int socket_shutdown_write(Socket_T S);
+
+
 #endif
