@@ -155,7 +155,7 @@ static pthread_mutex_t *ssl_mutex_table;
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: ssl.c,v 1.66 2009/02/13 09:18:10 hauk Exp $
+ *  @version \$Id: ssl.c,v 1.69 2009/05/03 21:29:42 martinp Exp $
  *
  *  @file
  */
@@ -389,7 +389,7 @@ ssl_server_connection *init_ssl_server(char *pemfile, char *clientpemfile) {
 
 sslerror:
 
-  cleanup_ssl_server_socket(ssl_server);
+  delete_ssl_server_socket(ssl_server);
 
   return NULL;
 
@@ -626,7 +626,7 @@ void stop_ssl() {
     CRYPTO_set_id_callback(NULL);
     CRYPTO_set_locking_callback(NULL);
     for(i= 0; i < CRYPTO_num_locks(); i++)
-      pthread_mutex_destroy(&ssl_mutex_table[i]);
+      assert(pthread_mutex_destroy(&ssl_mutex_table[i]) == 0);
     FREE(ssl_mutex_table);
     RAND_cleanup();
   }
@@ -906,9 +906,9 @@ static int unsigned long ssl_thread_id() {
 static void ssl_mutex_lock(int mode, int n, const char *file, int line) {
 
   if(mode & CRYPTO_LOCK)
-    pthread_mutex_lock( & ssl_mutex_table[n]);
+    assert(pthread_mutex_lock( & ssl_mutex_table[n]) == 0);
   else
-    pthread_mutex_unlock( & ssl_mutex_table[n]);
+    assert(pthread_mutex_unlock( & ssl_mutex_table[n]) == 0);
   
 }
 
