@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 #include <config.h>
@@ -59,7 +70,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: status.c,v 1.63 2007/07/25 12:54:30 hauk Exp $
+ *  @version \$Id: status.c,v 1.69 2009/02/13 09:18:11 hauk Exp $
  *
  *  @file
  */
@@ -92,7 +103,7 @@ int status(char *level) {
     return status;
   }
 
-  auth= Util_getBasicAuthHeader();
+  auth= Util_getBasicAuthHeaderMonit();
   socket_print(sock, 
 	       "GET /_status?format=text&level=%s HTTP/1.0\r\n%s\r\n",
 	       level, auth?auth:"");
@@ -100,7 +111,7 @@ int status(char *level) {
 
   /* Read past HTTP headers and check status */
   while(socket_readln(sock, buf, LINE)) {
-    if(IS(buf, "\n") || IS(buf, "\r\n"))
+    if(*buf == '\n' || *buf == '\r')
       break;
     if(Util_startsWith(buf, "HTTP/1.0 200"))
       status= TRUE;
