@@ -160,7 +160,7 @@ struct ad_user {
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Michael Amster, <mamster@webeasy.com> 
  *
- *  @version \$Id: util.c,v 1.231 2009/04/11 20:06:01 martinp Exp $
+ *  @version \$Id: util.c,v 1.241 2009/05/28 21:35:30 martinp Exp $
  *  @file
  */
 
@@ -1297,12 +1297,13 @@ char *Util_monitId(char *idfile) {
       LogError("%s: idfile '%s' is not a regular file\n", prog, idfile);
       return NULL;
     }
-    if((file= fopen(idfile,"r")) == (FILE *)NULL) {
+    if((file = fopen(idfile,"r")) == (FILE *)NULL) {
       LogError("%s: Error opening the idfile '%s' -- %s\n", prog, idfile, STRERROR);
       return NULL;
     }
-    if(fscanf(file, "%s", Run.id) != 1) {
+    if(fscanf(file, "%256s", Run.id) != 1) {
       LogError("%s: Error reading id from file '%s'\n", prog, idfile);
+      fclose(file);
       return NULL;
     }
   }
@@ -1337,6 +1338,7 @@ pid_t Util_getPid(char *pidfile) {
   }
   if(fscanf(file, "%d", &pid) != 1) {
     LogError("%s: Error reading pid from file '%s'\n", prog, pidfile);
+    fclose(file);
     return FALSE;
   }
   fclose(file);
@@ -1384,16 +1386,16 @@ int Util_isProcessRunning(Service_T s) {
 char *Util_getRFC822Date(time_t *date, char *result, int len) {
   
   struct tm *tm_now;
-  time_t now= (date && *date>0)?*date:time(NULL);
+  time_t now = (date && *date > 0) ? *date : time(NULL);
   
-  tm_now= localtime(&now);
+  tm_now = localtime(&now);
+  if (! tm_now)
+    return NULL;
   
-  if(strftime(result, len, "%a, %d %b %Y %H:%M:%S %z", tm_now) <= 0) {
+  if (strftime(result, len, "%a, %d %b %Y %H:%M:%S %z", tm_now) <= 0) {
     *result= 0;
   }
-  
   return result;
-  
 }
 
 
@@ -1429,29 +1431,28 @@ time_t Util_getProcessUptime(char *pidfile) {
  */
 char *Util_getUptime(time_t delta, char *sep) {
 
-  static int min= 60;
-  static int hour= 3600;
-  static int day= 86400;
+  static int min = 60;
+  static int hour = 3600;
+  static int day = 86400;
   long rest_d;
   long rest_h;
   long rest_m;
   char buf[STRLEN];
-  char *p= buf;
+  char *p = buf;
 
-  *buf= 0;
+  *buf = 0;
   if(delta < 0)
     return(xstrdup(""));
-  if((rest_d= delta/day)>0) {
-    p+= snprintf(p, STRLEN-(p-buf), "%ldd%s", rest_d,sep);
-    delta-= rest_d*day;
+  if((rest_d = delta/day)>0) {
+    p += snprintf(p, STRLEN-(p-buf), "%ldd%s", rest_d,sep);
+    delta -= rest_d*day;
   }
-  if((rest_h= delta/hour)>0 || (rest_d > 0)) {
-    p+= snprintf(p, STRLEN-(p-buf),"%ldh%s", rest_h,sep);
-    delta-= rest_h*hour;
+  if((rest_h = delta/hour)>0 || (rest_d > 0)) {
+    p += snprintf(p, STRLEN-(p-buf), "%ldh%s", rest_h,sep);
+    delta -= rest_h*hour;
   }
-  rest_m= delta/min;
-  p+= snprintf(p, STRLEN-(p-buf),"%ldm%s", rest_m,sep);
-  delta-= rest_m*min;
+  rest_m = delta/min;
+  snprintf(p, STRLEN - (p - buf), "%ldm%s", rest_m, sep);
   
   return xstrdup(buf);
 
@@ -1689,8 +1690,7 @@ void Util_redirectStdFds() {
   int i;
   for(i= 0; i < 3; i++) {
     if(close(i) == -1 || open("/dev/null", O_RDWR) != i) {
-      LogError("Cannot reopen standard file descriptor (%d) -- %s\n",
-        i, STRERROR);
+      LogError("Cannot reopen standard file descriptor (%d) -- %s\n", i, STRERROR);
     }
   }
 }
@@ -1872,7 +1872,8 @@ int Util_checkCredentials(char *uname, char *outside) {
   }
   switch (c->digesttype) {
     case DIGEST_CLEARTEXT:
-      strncpy(outside_crypt, outside, STRLEN); 
+      outside_crypt[sizeof(outside_crypt) - 1] = 0;
+      strncpy(outside_crypt, outside, sizeof(outside_crypt) - 1); 
       break;
     case DIGEST_MD5:
     {
@@ -1883,14 +1884,16 @@ int Util_checkCredentials(char *uname, char *outside) {
        *   $id$salt$digest
        * the '$' around the id are still part of the id. 
        */
-      strncpy(id, c->passwd, STRLEN);
+      id[sizeof(id) - 1] = 0;
+      strncpy(id, c->passwd, sizeof(id) - 1);
       if(! (temp= strchr(id+1, '$'))) {
         LogError("Password not in MD5 format.\n");
 	return FALSE;
       }
       temp += 1;
       *temp= '\0';
-      strncpy(salt, c->passwd+strlen(id), STRLEN);
+      salt[sizeof(salt) - 1] = 0;
+      strncpy(salt, c->passwd+strlen(id), sizeof(salt) - 1);
       if(! (temp= strchr(salt, '$'))) {
         LogError("Password not in MD5 format.\n");
 	return FALSE;
@@ -1908,7 +1911,8 @@ int Util_checkCredentials(char *uname, char *outside) {
       char * temp;
       snprintf(salt, 3, "%c%c", c->passwd[0], c->passwd[1]);
       temp= crypt(outside, salt);
-      strncpy(outside_crypt, temp, STRLEN); 
+      outside_crypt[sizeof(outside_crypt) - 1] = 0;
+      strncpy(outside_crypt, temp, sizeof(outside_crypt) - 1); 
       break;
     }
 #ifdef HAVE_LIBPAM
@@ -2126,19 +2130,19 @@ void Util_monitorUnset(Service_T s) {
  */
 int Util_getAction(const char *action) {
 
-  char *name;
   /* the ACTION_IGNORE has index 0 => we will start on next item */
   int   i = 1;
 
   ASSERT(action);
 
-  for(name = actionnames[i]; strlen(actionnames[i]); i++)
+  while(strlen(actionnames[i]))
   {
     if(IS(action, actionnames[i]))
     {
       /* supported action found */
       return i;
     }
+    i++;
   }
   /* the action was not found */
   return ACTION_IGNORE;
