@@ -1,11 +1,8 @@
 /*
- * Copyright (C), 2000-2007 by the monit project group.
- * All Rights Reserved.
+ * Copyright (C) 2009 Tildeslash Ltd. All rights reserved.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,6 +11,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * In addition, as a special exception, the copyright holders give
+ * permission to link the code of portions of this program with the
+ * OpenSSL library under certain conditions as described in each
+ * individual source file, and distribute linked combinations
+ * including the two.
+ *
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * file(s) with this exception, you may extend this exception to your
+ * version of the file(s), but you are not obligated to do so.  If you
+ * do not wish to do so, delete this exception statement from your
+ * version.  If you delete this exception statement from all source
+ * files in the program, then also delete it here.
  */
 
 
@@ -29,7 +40,7 @@
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Michael Amster, <mamster@webeasy.com> 
  *
- *  @version \$Id: util.h,v 1.19 2007/10/16 03:05:41 hauk Exp $
+ *  @version \$Id: util.h,v 1.27 2009/03/11 20:31:27 hauk Exp $
  *  @file
  */
 
@@ -83,6 +94,25 @@ char *Util_rtrim(char *s);
 void Util_trimQuotes(char *s);
 
 
+/**
+ * Truncate <code>s</code> at <code>n</code> and add a trailing "..." 
+ * to the end of <code>s</code>. If <code>s</code> is shorter than 
+ * <code>n</code> or has no space for the trail, <code>s</code> is left
+ * untouched otherwise this function modifies <code>s</code>. 
+ * <pre>
+ * Example: 
+ *  char s[]= "Hello World!";
+ *  Util_trunc(s, strlen(s)); --> "Hello World!" 
+ *  Util_trunc(s, 5); --> "Hello..."
+ *  Util_trunc(s, 0); --> "..."
+ * </pre>
+ * @param s String to truncate at n
+ * @param n number of bytes from where s is truncated
+ * @return A pointer to s
+ */
+char *Util_trunc(char *s, int n);
+
+
 /**
  * Replace all occurrences of the <code>old</code> char in the string
  * <code>s</code> with the <code>new</code> char.
@@ -202,6 +232,15 @@ void Util_printServiceList();
 void Util_printHash(char *filename);
 
 
+/**
+ * Open and read the id from the given idfile. If the idfile doesn't exist,
+ * generate new id and store it in the id file.
+ * @param idfile An idfile with full path
+ * @return the id or NULL
+ */
+char *Util_monitId(char *idfile);
+
+
 /**
  * Open and read the pid from the given pidfile.
  * @param pidfile A pidfile with full path
@@ -277,7 +316,14 @@ char *Util_urlDecode(char *url);
  * @return a Basic Authentication Authorization string (RFC 2617),
  * with credentials from the Run object, NULL if credentials are not defined.
  */
-char *Util_getBasicAuthHeader();
+char *Util_getBasicAuthHeaderMonit();
+
+
+/**
+ * @return a Basic Authentication Authorization string (RFC 2617),
+ * NULL if username is not defined.
+ */
+char *Util_getBasicAuthHeader(char *username, char *password);
 
 
 /**
