@@ -101,7 +101,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: validate.c,v 1.199 2009/03/24 22:00:11 martinp Exp $
+ *  @version \$Id: validate.c,v 1.200 2009/05/04 21:07:34 martinp Exp $
  *  @file
  */
 
@@ -1022,7 +1022,6 @@ static void check_size(Service_T s) {
 static void check_match(Service_T s) {
   int  advance = 0;
   int  length = 0;
-  int  ignore;
   FILE *file;
   char line[MATCH_LINE_LENGTH];
     
@@ -1043,7 +1042,6 @@ static void check_match(Service_T s) {
   }
 
   while (TRUE) {
-    ignore = FALSE;
     
     /* Seek to the read position */
     if (fseek(file, s->inf->readpos, SEEK_SET)) {
