@@ -60,7 +60,7 @@
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: xml.c,v 1.55 2009/03/28 10:37:43 martinp Exp $
+ *  @version \$Id: xml.c,v 1.56 2009/04/21 21:32:10 martinp Exp $
  *
  *  @file
  */
@@ -435,7 +435,7 @@ static void status_event(Event_T E, Buffer_T *B) {
     "\t\t<message>%s</message>\r\n",
     tv->tv_sec,
     tv->tv_usec,
-    Event_get_source_name(E),
+    Event_get_id(E) == EVENT_INSTANCE ? "Monit" : Event_get_source_name(E),
     Event_get_source_type(E),
     Event_get_source_group(E),
     Event_get_id(E),
